@@ -14,6 +14,7 @@ import { ChatboxContext } from '../Components/ChatboxContext';
 import { ChatRequestStatus } from '../types';
 import { AppStateService } from '../AppState';
 import { NotebookCellStateService } from '../Services/NotebookCellStateService';
+import { convertMentionsToContextTags } from '../utils/contextTagUtils';
 
 /**
  * Input element type that supports both textarea and rich text input
@@ -544,11 +545,16 @@ export class ChatInputManager {
     // Clear the input
     this.clearInput();
 
-    // Display the user message in the UI
-    this.messageComponent.addUserMessage(userInput);
+    // Convert @mentions to context tags for message processing
+    const processedUserInput = convertMentionsToContextTags(userInput, this.activeContexts);
+    console.log('[ChatInputManager] Original message:', userInput);
+    console.log('[ChatInputManager] Processed message with context tags:', processedUserInput);
 
-    // Initialize messages with the user query
-    const newUserMessage = { role: 'user', content: userInput };
+    // Display the user message in the UI (with context tags for proper styling)
+    this.messageComponent.addUserMessage(processedUserInput);
+
+    // Initialize messages with the user query (with context tags for API processing)
+    const newUserMessage = { role: 'user', content: processedUserInput };
 
     try {
       // Make sure the conversation service knows which notebook we're targeting
