@@ -35,9 +35,6 @@ export class ChatUIHelper {
   public resetToGeneratingState(text: string = 'Generating...'): void {
     // Force show LLM state display in generating mode, clearing any existing state
     this.llmStateDisplay.show(text);
-
-    // Ensure the chat container is scrolled to the bottom
-    this.chatHistory.scrollTop = this.chatHistory.scrollHeight;
   }
 
   /**
@@ -61,9 +58,6 @@ export class ChatUIHelper {
 
     // Show LLM state display with the status text
     this.llmStateDisplay.show(text);
-
-    // Ensure the chat container is scrolled to the bottom
-    this.chatHistory.scrollTop = this.chatHistory.scrollHeight;
   }
 
   /**
