@@ -1,7 +1,7 @@
 import { ChatMessages } from './ChatMessages';
 import { ToolService } from '../Services/ToolService';
 import { IChatService } from '../Services/IChatService';
-import { ChatRequestStatus, DiffApprovalStatus } from '../types';
+import { ChatRequestStatus } from '../types';
 import { NotebookStateService } from '../Notebook/NotebookStateService';
 import { CodeConfirmationDialog } from '../Components/CodeConfirmationDialog';
 import { RejectionFeedbackDialog } from '../Components/RejectionFeedbackDialog';
@@ -12,14 +12,14 @@ import {
 } from './ActionHistory';
 import { NotebookDiffManager } from '../Notebook/NotebookDiffManager';
 import { Contents } from '@jupyterlab/services';
-import { SettingsWidget } from '../Components/Settings/SettingsWidget';
 import { AppStateService } from '../AppState';
 import {
-  ConversationServiceUtils,
   ConversationContext,
+  ConversationServiceUtils,
   StreamingState
 } from './ConversationServiceUtils';
 import { DiffStateService } from '../Services/DiffStateService';
+import { STATE_DB_KEYS, StateDBCachingService } from '../utils/stateDBCaching';
 
 export interface LoadingIndicatorManager {
   updateLoadingIndicator(text?: string): void;
@@ -41,7 +41,7 @@ export class ConversationService {
   private diffManager: NotebookDiffManager | null = null;
   private isActiveToolExecution: boolean = false; // Track if we're in a tool execution phase
   private autoRun: boolean = false; // New flag to control automatic code execution
-  private notebookPath: string | null = null;
+  private notebookId: string | null = null;
   private streamingElement: HTMLDivElement | null = null; // Element for streaming text
   private contentManager: Contents.IManager;
 
@@ -55,8 +55,7 @@ export class ConversationService {
     messageComponent: ChatMessages,
     chatHistory: HTMLDivElement,
     loadingManager: LoadingIndicatorManager,
-    diffManager?: NotebookDiffManager,
-    autorunCheckbox?: HTMLInputElement
+    diffManager?: NotebookDiffManager
   ) {
     this.chatService = chatService;
     this.toolService = toolService;
@@ -67,27 +66,20 @@ export class ConversationService {
     this.diffManager = diffManager || null;
     this.contentManager = contentManager;
 
-    const onActivateAutoRunMode = () => {
-      if (autorunCheckbox) {
-        autorunCheckbox.click();
-      }
-    };
-
     // Initialize dependent services
     this.notebookStateService = new NotebookStateService(toolService);
     this.codeConfirmationDialog = new CodeConfirmationDialog(
       chatHistory,
-      messageComponent,
-      onActivateAutoRunMode
+      messageComponent
     );
 
     // Ensure chat service has the full conversation history
     this.syncChatServiceHistory();
   }
 
-  public updateNotebookPath(newPath: string): void {
-    this.notebookPath = newPath;
-    this.notebookStateService.updateNotebookPath(newPath);
+  public updateNotebookId(newId: string): void {
+    this.notebookId = newId;
+    this.notebookStateService.updateNotebookId(newId);
   }
 
   /**
@@ -113,6 +105,10 @@ export class ConversationService {
       }
     }
 
+    if (messageHistory.length > 0) {
+      this.messageComponent.scrollToBottom();
+    }
+
     console.log(
       `Synchronized ${messageHistory.length} messages to chat service history`
     );
@@ -136,12 +132,12 @@ export class ConversationService {
   }
 
   /**
-   * Set the current notebook path
-   * @param notebookPath Path to the notebook to interact with
+   * Set the current notebook ID
+   * @param notebookId ID of the notebook to interact with
    */
-  public setNotebookPath(notebookPath: string): void {
-    this.notebookPath = notebookPath;
-    console.log(`[ConversationService] Set notebook path: ${notebookPath}`);
+  public setNotebookId(notebookId: string): void {
+    this.notebookId = notebookId;
+    console.log(`[ConversationService] Set notebook ID: ${notebookId}`);
   }
 
   /**
@@ -173,7 +169,7 @@ export class ConversationService {
   }
 
   /**
-   * Process a tool call ensuring the notebook path is passed through
+   * Process a tool call ensuring the notebook ID is passed through
    */
   private async processToolCall(toolCall: any): Promise<any> {
     return await ConversationServiceUtils.processToolCall(
@@ -187,7 +183,7 @@ export class ConversationService {
         diffManager: this.diffManager,
         actionHistory: this.actionHistory,
         autoRun: this.autoRun,
-        notebookPath: this.notebookPath,
+        notebookId: this.notebookId,
         templates: this.templates,
         isActiveToolExecution: this.isActiveToolExecution,
         chatHistory: this.chatHistory
@@ -213,7 +209,7 @@ export class ConversationService {
         diffManager: this.diffManager,
         actionHistory: this.actionHistory,
         autoRun: this.autoRun,
-        notebookPath: this.notebookPath,
+        notebookId: this.notebookId,
         templates: this.templates,
         isActiveToolExecution: this.isActiveToolExecution,
         chatHistory: this.chatHistory
@@ -226,32 +222,36 @@ export class ConversationService {
     console.log('Creating error message dump...');
     console.log(message);
     try {
-      let fileExists = false;
-      try {
-        await this.contentManager.get('./error_dump.txt');
-        fileExists = true;
-      } catch (e) {
-        fileExists = false;
-      }
-      if (!fileExists) {
-        await this.contentManager.save('./error_dump.txt', {
-          type: 'file',
-          format: 'text',
-          content: ''
-        });
+      // Get existing error logs from stateDB
+      const existingLogs = await StateDBCachingService.getValue(
+        STATE_DB_KEYS.ERROR_LOGS,
+        ''
+      );
+
+      // Create new log entry
+      const newLogEntry = `\n\n---\n\n${new Date().toISOString()}\n\n${JSON.stringify(message)}`;
+      let updatedLogs = existingLogs + newLogEntry;
+
+      // Trim logs to stay within 100,000 words limit
+      const words = updatedLogs.split(/\s+/);
+      if (words.length > 100000) {
+        // Keep only the most recent 90,000 words to leave room for future entries
+        const trimmedWords = words.slice(-90000);
+        updatedLogs = trimmedWords.join(' ');
+
+        // Add a marker to indicate logs were trimmed
+        updatedLogs =
+          '[...logs trimmed to maintain 100,000 word limit...]\n\n' +
+          updatedLogs;
       }
 
-      const current = await this.contentManager.get('./error_dump.txt');
-      let content = current.content || '';
-
-      content += `\n\n---\n\n${new Date().toISOString()}\n\n${message}`;
-      await this.contentManager.save('./error_dump.txt', {
-        type: 'file',
-        format: 'text',
-        content: content
-      });
+      // Save back to stateDB
+      await StateDBCachingService.setValue(
+        STATE_DB_KEYS.ERROR_LOGS,
+        updatedLogs
+      );
     } catch (err) {
-      console.error(err);
+      console.error('Failed to save error log to stateDB:', err);
     }
   }
 
@@ -274,7 +274,7 @@ export class ConversationService {
       diffManager: this.diffManager,
       actionHistory: this.actionHistory,
       autoRun: this.autoRun,
-      notebookPath: this.notebookPath,
+      notebookId: this.notebookId,
       templates: this.templates,
       isActiveToolExecution: this.isActiveToolExecution,
       chatHistory: this.chatHistory
@@ -284,13 +284,14 @@ export class ConversationService {
     const streamingState: StreamingState = {
       currentStreamingMessage: null,
       currentStreamingToolCall: null,
-      streamingToolCall: undefined
+      streamingToolCall: undefined,
+      operationQueue: {}
     };
 
     try {
       // Step 1: Initialize conversation processing
       const { preparedMessages, tools } =
-        ConversationServiceUtils.initializeConversation(
+        await ConversationServiceUtils.initializeConversation(
           context,
           newMessages,
           systemPromptMessages,
@@ -360,10 +361,13 @@ export class ConversationService {
       // Handle recursive call for continuing conversation after tool use
       if (hasToolCalls) {
         // Check if user has made approval decisions that should stop the LLM loop
-        const hasApprovalDecisions = ConversationServiceUtils.checkForApprovalDecisions(context);
-        
+        const hasApprovalDecisions =
+          ConversationServiceUtils.checkForApprovalDecisions(context);
+
         if (hasApprovalDecisions) {
-          console.log('[ConversationService] Approval decisions detected - stopping recursive LLM loop');
+          console.log(
+            '[ConversationService] Approval decisions detected - stopping recursive LLM loop'
+          );
           return; // Stop the recursive loop
         }
 
@@ -375,7 +379,7 @@ export class ConversationService {
             content.name !== 'notebook-wait_user_reply'
           ) {
             if (content.name === 'notebook-run_cell')
-              DiffStateService.getInstance().clearAllDiffs(this.notebookPath);
+              DiffStateService.getInstance().clearAllDiffs(this.notebookId);
             needsRecursiveCall = true;
             break;
           }
@@ -391,10 +395,7 @@ export class ConversationService {
       }
 
       // Step 7: Handle pending diffs if no tool calls were made
-      await ConversationServiceUtils.handlePendingDiffsAfterToolCalls(
-        context,
-        hasToolCalls
-      );
+      await ConversationServiceUtils.handlePendingDiffsAfterToolCalls(context);
 
       // Update instance state from context
       this.isActiveToolExecution = context.isActiveToolExecution;
