@@ -1475,11 +1475,21 @@ export class ConversationServiceUtils {
 
     // For each executed cell, add the tool result to the conversation
     for (const { cellId, result } of cellsToReport) {
+      if (cellId !== requestedCellId) continue;
+
+      let final_res = result;
+      if (Array.isArray(result)) {
+        for (const res of result as any[]) {
+          if (typeof res === 'string') final_res += res;
+          else final_res += JSON.stringify(res);
+        }
+      }
+
       // Format the result as a tool result
       const toolResult = {
         type: 'tool_result' as const,
         tool_use_id: contentId,
-        content: Array.isArray(result) ? result.join('\n') : String(result)
+        content: final_res
       };
 
       // Add the tool result to the conversation
