@@ -41,6 +41,10 @@ export class CodebaseManager {
     const container = document.createElement('div');
     container.className = 'sage-ai-codebase-manager';
 
+    // This feature is not maintained yet
+    // Softly hide it for now
+    container.style.display = 'none';
+
     // Create section title
     const title = document.createElement('h3');
     title.textContent = 'Codebase Search';
