@@ -5,6 +5,7 @@ import { AppStateService } from '../../AppState';
 import { diffStateService } from '../../Services/DiffStateService';
 import { RUN_CELL_ICON } from './icons';
 import { REAPPLY_ICON } from '../icons';
+import { NotebookDiffTools } from '../../Notebook/NotebookDiffTools';
 
 /**
  * Spinner component for running state
@@ -80,18 +81,23 @@ export function DiffItem({
   const getLineChanges = (
     diff: IPendingDiff
   ): { added: number; removed: number } => {
-    const originalLines = diff.originalContent?.split('\n').length || 0;
-    const newLines = diff.newContent?.split('\n').length || 0;
-
     if (diff.type === 'add') {
+      // For new cells, count all lines as added
+      const newLines = diff.newContent?.split('\n').length || 0;
       return { added: newLines, removed: 0 };
     } else if (diff.type === 'remove') {
+      // For removed cells, count all lines as removed
+      const originalLines = diff.originalContent?.split('\n').length || 0;
       return { added: 0, removed: originalLines };
     } else if (diff.type === 'edit') {
-      return {
-        added: Math.max(0, newLines - originalLines),
-        removed: Math.max(0, originalLines - newLines)
-      };
+      const diffLines = NotebookDiffTools.calculateDiff(
+        diff.originalContent || '',
+        diff.newContent || ''
+      );
+      const added = diffLines.filter(line => line.type === 'added').length;
+      const removed = diffLines.filter(line => line.type === 'removed').length;
+
+      return { added, removed };
     }
     return { added: 0, removed: 0 };
   };
@@ -113,6 +119,7 @@ export function DiffItem({
   const isDecisionMade =
     diffState.userDecision !== null && diffState.userDecision !== undefined;
   const isRunning = diffState.userDecision === 'run' && !diffState.runResult;
+  const isEditDiff = diffState.type === 'edit';
 
   // Add CSS animation for spinner if not already added
   React.useEffect(() => {
@@ -166,7 +173,7 @@ export function DiffItem({
         </div>
       </div>
 
-      {isDecisionMade && (
+      {isDecisionMade && isEditDiff && (
         <div className="sage-ai-diff-actions">
           <button
             onClick={() => {
@@ -222,11 +229,6 @@ export function DiffItem({
           <button
             className="sage-ai-diff-btn sage-ai-diff-run"
             onClick={() => {
-              // Update diff state using RxJS service to "run"
-              diffStateService.updateDiffStateToRun(
-                diffState.cellId,
-                diffState.notebookId
-              );
               // Also trigger the dialog action if needed
               AppStateService.getNotebookDiffManager().diffApprovalDialog.runCell(
                 diffState.cellId
