@@ -6,6 +6,7 @@ import { IPendingDiff } from '../../types';
 import { MENU_CLOSE_ICON, MENU_ICON } from './icons';
 import { getToolDisplayMessage, getToolIcon } from '../../utils/toolDisplay';
 import { diffStateService } from '../../Services/DiffStateService';
+import { NotebookDiffTools } from '../../Notebook/NotebookDiffTools';
 
 /**
  * React component for displaying LLM processing state content
@@ -78,16 +79,24 @@ export function LLMStateContent({
     let totalRemoved = 0;
 
     diffs.forEach(diff => {
-      const originalLines = diff.originalContent?.split('\n').length || 0;
-      const newLines = diff.newContent?.split('\n').length || 0;
+      const oldLines = diff.originalContent?.split('\n') || [];
+      const oldLinesCount = oldLines.length;
+      const newLines = diff.newContent?.split('\n') || [];
+      const newLinesCount = newLines.length;
 
       if (diff.type === 'add') {
-        totalAdded += newLines;
+        totalAdded += newLinesCount;
       } else if (diff.type === 'remove') {
-        totalRemoved += originalLines;
+        totalRemoved += oldLinesCount;
       } else if (diff.type === 'edit') {
-        totalAdded += Math.max(0, newLines - originalLines);
-        totalRemoved += Math.max(0, originalLines - newLines);
+        const diffLines = NotebookDiffTools.calculateDiff(
+          diff.originalContent || '',
+          diff.newContent || ''
+        );
+        totalAdded += diffLines.filter(line => line.type === 'added').length;
+        totalRemoved += diffLines.filter(
+          line => line.type === 'removed'
+        ).length;
       }
     });
 
@@ -225,14 +234,16 @@ export function LLMStateContent({
               {displayDiffs.length} cell{displayDiffs.length !== 1 ? 's' : ''}{' '}
               modified
             </span>
-            {totalAdded > 0 && (
-              <span className="sage-ai-diff-added-count">+{totalAdded}</span>
-            )}
-            {totalRemoved > 0 && (
-              <span className="sage-ai-diff-removed-count">
-                -{totalRemoved}
-              </span>
-            )}
+            <p className="sage-ai-diff-cell-count-info">
+              {totalAdded > 0 && (
+                <span className="sage-ai-diff-added-count">+{totalAdded}</span>
+              )}
+              {totalRemoved > 0 && (
+                <span className="sage-ai-diff-removed-count">
+                  -{totalRemoved}
+                </span>
+              )}
+            </p>
           </div>
           <div className="sage-ai-diff-summary-actions">
             {!allDiffsResolved && (
@@ -253,9 +264,9 @@ export function LLMStateContent({
                     await AppStateService.getNotebookDiffManager().diffApprovalDialog.rejectAll();
                     setAllDiffsResolved(true);
                   }}
-                  title="Reject all changes"
+                  title={`Reject ${diffs && diffs.length > 1 && 'all'} changes`}
                 >
-                  Reject All
+                  {diffs && diffs.length > 1 ? 'Reject All' : 'Reject'}
                 </button>
                 <button
                   className="sage-ai-diff-btn sage-ai-diff-approve-all"
@@ -263,35 +274,23 @@ export function LLMStateContent({
                     e.stopPropagation();
 
                     if (isRunContext) {
-                      // For run context, use runCell for each diff
                       for (const diff of displayDiffs) {
                         if (!diff.userDecision) {
-                          // Update DiffStateService first
-                          diffStateService.updateDiffStateToRun(
-                            diff.cellId,
-                            diff.notebookId
-                          );
-                          // Then trigger the dialog action
                           await AppStateService.getNotebookDiffManager().diffApprovalDialog.runCell(
                             diff.cellId
                           );
                         }
                       }
                     } else {
-                      // For regular approval, update DiffStateService first
-                      for (const diff of displayDiffs) {
-                        diffStateService.updateDiffState(
-                          diff.cellId,
-                          true,
-                          diff.notebookId
-                        );
-                      }
-                      // Then trigger the dialog action
                       await AppStateService.getNotebookDiffManager().diffApprovalDialog.approveAll();
                     }
                     setAllDiffsResolved(true);
                   }}
-                  title="Approve all changes"
+                  title={
+                    isRunContext
+                      ? `Run ${diffs && diffs.length > 1 && 'all'} changes`
+                      : `Approve ${diffs && diffs.length > 1 && 'all'} changes`
+                  }
                 >
                   {isRunContext
                     ? `${diffs && diffs.length > 1 ? 'Run All' : 'Run'}`
