@@ -55,8 +55,9 @@ function SettingsContent({
     React.useState<CodebaseManager | null>(null);
   const codebaseContainerRef = React.useRef<HTMLDivElement>(null);
   const [isApiKeyFocused, setIsApiKeyFocused] = React.useState<boolean>(false);
-  const [isDatabaseUrlFocused, setIsDatabaseUrlFocused] = React.useState<boolean>(false);
-  
+  const [isDatabaseUrlFocused, setIsDatabaseUrlFocused] =
+    React.useState<boolean>(false);
+
   // Database cache state
   const [cacheStatus, setCacheStatus] = React.useState<{
     isCached: boolean;
@@ -66,7 +67,10 @@ function SettingsContent({
   const [isRefreshing, setIsRefreshing] = React.useState<boolean>(false);
 
   // Get database cache instance
-  const databaseCache = React.useMemo(() => DatabaseMetadataCache.getInstance(), []);
+  const databaseCache = React.useMemo(
+    () => DatabaseMetadataCache.getInstance(),
+    []
+  );
 
   // Update cache status periodically
   React.useEffect(() => {
@@ -101,7 +105,10 @@ function SettingsContent({
     try {
       await databaseCache.refreshMetadata(databaseUrl);
     } catch (error) {
-      console.error('[SettingsWidget] Failed to refresh database metadata:', error);
+      console.error(
+        '[SettingsWidget] Failed to refresh database metadata:',
+        error
+      );
     } finally {
       setIsRefreshing(false);
     }
@@ -110,12 +117,12 @@ function SettingsContent({
   // Format last updated time
   const formatLastUpdated = (timestamp: number | null): string => {
     if (!timestamp) return 'Never';
-    
+
     const now = Date.now();
     const diff = now - timestamp;
     const minutes = Math.floor(diff / 60000);
     const seconds = Math.floor((diff % 60000) / 1000);
-    
+
     if (minutes > 0) {
       return `${minutes}m ${seconds}s ago`;
     } else {
@@ -156,14 +163,14 @@ function SettingsContent({
 
   return (
     <div className="sage-ai-settings-container">
-      <h2 className="sage-ai-settings-title">Sage AI Settings</h2>
+      <h2 className="sage-ai-settings-title">Sage Settings</h2>
 
       {/* Codebase Manager Container */}
       <div ref={codebaseContainerRef} />
 
       {/* Claude API Configuration */}
       <div className="sage-ai-config-section">
-        <h3 className="sage-ai-config-title">Sage API Configuration</h3>
+        <h3 className="sage-ai-config-title">API Configuration</h3>
 
         <div className="sage-ai-field-container">
           <label className="sage-ai-field-label">Sage API Key:</label>
@@ -219,7 +226,9 @@ function SettingsContent({
             />
             <button
               onClick={handleRefreshMetadata}
-              disabled={!databaseUrl || databaseUrl.trim() === '' || isRefreshing}
+              disabled={
+                !databaseUrl || databaseUrl.trim() === '' || isRefreshing
+              }
               className="sage-ai-refresh-button"
               title="Refresh database metadata cache"
             >
@@ -233,17 +242,22 @@ function SettingsContent({
               )}
             </button>
           </div>
-          
+
           {/* Cache Status */}
           <div className="sage-ai-cache-status">
-            <span className={`sage-ai-cache-indicator ${cacheStatus.isCached ? (cacheStatus.isExpired ? 'expired' : 'cached') : 'not-cached'}`}>
-              {cacheStatus.isCached ? (cacheStatus.isExpired ? '⚠️' : '✓') : '○'}
+            <span
+              className={`sage-ai-cache-indicator ${cacheStatus.isCached ? (cacheStatus.isExpired ? 'expired' : 'cached') : 'not-cached'}`}
+            >
+              {cacheStatus.isCached
+                ? cacheStatus.isExpired
+                  ? '⚠️'
+                  : '✓'
+                : '○'}
             </span>
             <span className="sage-ai-cache-text">
               {cacheStatus.isCached
                 ? `Metadata cached (${formatLastUpdated(cacheStatus.lastUpdated)})${cacheStatus.isExpired ? ' - Expired' : ''}`
-                : 'No metadata cached'
-              }
+                : 'No metadata cached'}
             </span>
           </div>
         </div>
@@ -447,11 +461,15 @@ export class SettingsWidget extends ReactWidget {
     // Set DB_URL environment variable in kernel if configured
     console.log('[SettingsWidget] Database URL from settings:', databaseUrl);
     if (databaseUrl && databaseUrl.trim() !== '') {
-      console.log('[SettingsWidget] Setting DB_URL in kernel during settings load');
+      console.log(
+        '[SettingsWidget] Setting DB_URL in kernel during settings load'
+      );
       // Use retry mechanism since kernel might not be ready yet
       KernelUtils.setDbUrlInKernelWithRetry(databaseUrl);
     } else {
-      console.log('[SettingsWidget] No database URL configured, skipping DB_URL setup');
+      console.log(
+        '[SettingsWidget] No database URL configured, skipping DB_URL setup'
+      );
     }
   }
 
@@ -543,7 +561,9 @@ export class SettingsWidget extends ReactWidget {
 
     // Clear metadata cache if database URL is empty
     if (!value || value.trim() === '') {
-      console.log('[SettingsWidget] Database URL cleared, clearing metadata cache');
+      console.log(
+        '[SettingsWidget] Database URL cleared, clearing metadata cache'
+      );
       const databaseCache = DatabaseMetadataCache.getInstance();
       databaseCache.clearCache();
     }
@@ -557,8 +577,6 @@ export class SettingsWidget extends ReactWidget {
     this.update();
   }
 
-
-
   /**
    * Show the settings widget
    */
