@@ -759,6 +759,11 @@ export class ChatBoxWidget extends Widget {
       this.sendContinueMessage();
     });
 
+    // Set up the prompt callback to send custom prompt messages
+    waitingUserReplyBoxManager.setPromptCallback((prompt: string) => {
+      this.sendPromptMessage(prompt);
+    });
+
     // Initialize context display after everything is set up
     this.contextHandler.updateContextDisplay();
 
@@ -1573,6 +1578,17 @@ export class ChatBoxWidget extends Widget {
     this.messageComponent.hideWaitingReplyBox();
   }
 
+  public sendPromptMessage(prompt: string): void {
+    // Set the input value to the selected prompt
+    this.inputManager.setInputValue(prompt);
+    
+    // Send the message
+    this.inputManager.sendMessage();
+    
+    // Hide the waiting reply box since user has responded
+    this.messageComponent.hideWaitingReplyBox();
+  }
+
   /**
    * Gets the message component for external access
    */
