@@ -52,7 +52,7 @@ export class NotebookDiffManager {
       onReject: trackingIds => this.rejectDiffs(trackingIds),
       onApproveAll: notebookId => this.approveAllDiffs(notebookId),
       onRejectAll: notebookId => this.rejectAllDiffs(notebookId),
-      applyApprovedDiffs: notebookId => this.applyApprovedDiffs(notebookId),
+      applyApprovedDiffs: (...args) => this.applyApprovedDiffs(...args),
       handleRejectedDiffs: notebookId => this.handleRejectedDiffs(notebookId),
       setExecuteApprovedCells: execute => this.setExecuteApprovedCells(execute),
       reapplyDiff: diffCell => this.reapplyDiff(diffCell)
@@ -570,7 +570,7 @@ export class NotebookDiffManager {
 
   public rejectCellDiff(cellId: string): void {
     const diff = diffStateService.getCurrentState().pendingDiffs.get(cellId);
-    if (diff) {
+    if (diff && diff.approved !== false) {
       diffStateService.updateDiffState(cellId, false, diff.notebookId);
       this.handleRejectedDiffs(diff.notebookId);
     }
@@ -601,10 +601,12 @@ export class NotebookDiffManager {
   /**
    * Apply all approved diffs
    * @param notebookId Optional path to the notebook containing the cells
+   * @param trackingIds Optional array of tracking IDs to apply diffs for
    * @returns Promise resolving to a result object with success status and approval status
    */
   public async applyApprovedDiffs(
-    notebookId?: string | null
+    notebookId?: string | null,
+    trackingIds?: string[]
   ): Promise<IDiffApplicationResult> {
     const path = notebookId || this.currentNotebookId;
 
@@ -625,6 +627,11 @@ export class NotebookDiffManager {
         const tempModelId =
           diff.updatedCellId !== diff.cellId ? diff.updatedCellId : undefined;
 
+        const shouldApply = !trackingIds || trackingIds.includes(trackingId);
+        if (!shouldApply) {
+          continue;
+        }
+
         console.log('Searching for cell with tracking ID:', trackingId);
 
         // First try to find cell by tracking ID
@@ -789,7 +796,7 @@ export class NotebookDiffManager {
 
   public approveCellDiff(cellId: string): void {
     const diff = diffStateService.getCurrentState().pendingDiffs.get(cellId);
-    if (diff) {
+    if (diff && !diff.approved) {
       diffStateService.updateDiffState(cellId, true, diff.notebookId);
       this.applyApprovedDiffs(diff.notebookId);
     }
