@@ -140,7 +140,7 @@ export class NotebookDiffTools {
    * @param newText The new text
    * @returns An array of diff objects with line content and change type
    */
-  calculateDiff(
+  public static calculateDiff(
     oldText: string,
     newText: string
   ): Array<{ line: string; type: 'added' | 'removed' | 'unchanged' }> {
@@ -300,24 +300,21 @@ export class NotebookDiffTools {
       const mergeCallbacks: MergeCallbacks = {
         onApproveAll: (cellId: string) => {
           console.log(
-            `[NotebookDiffTools] Diff all resolved for cell ${cellId}`
+            `[NotebookDiffTools] Diff all approved for cell ${cellId}`
           );
           AppStateService.getNotebookDiffManager().approveCellDiff(cellId);
-          this.cleanupDiffMetadata(updatedCell);
         },
         onAllResolved: (cellId: string) => {
           console.log(
             `[NotebookDiffTools] Diff all resolved for cell ${cellId}`
           );
           AppStateService.getNotebookDiffManager().approveCellDiff(cellId);
-          this.cleanupDiffMetadata(updatedCell);
         },
         onRejectAll: (cellId: string) => {
           console.log(
-            `[NotebookDiffTools] Diff all resolved for cell ${cellId}`
+            `[NotebookDiffTools] Diff all rejected for cell ${cellId}`
           );
           AppStateService.getNotebookDiffManager().rejectCellDiff(cellId);
-          this.cleanupDiffMetadata(updatedCell);
         }
       };
 
@@ -521,34 +518,6 @@ export class NotebookDiffTools {
     }
   }
 
-  /**
-   * Accept all remaining chunks in a cell's merge view programmatically
-   * @param cell The cell to accept all chunks for
-   * @returns Promise<boolean> indicating success
-   */
-  async acceptAllChunks(cell: Cell): Promise<boolean> {
-    const cellId = (cell.model.sharedModel.getMetadata()?.cell_tracker as any)
-      ?.trackingId;
-    if (!cellId || !inlineDiffService) return false;
-
-    await inlineDiffService.acceptAllChunks(cellId);
-    return true;
-  }
-
-  /**
-   * Reject all remaining chunks in a cell's merge view programmatically
-   * @param cell The cell to reject all chunks for
-   * @returns Promise<boolean> indicating success
-   */
-  async rejectAllChunks(cell: Cell): Promise<boolean> {
-    const cellId = (cell.model.sharedModel.getMetadata()?.cell_tracker as any)
-      ?.trackingId;
-    if (!cellId || !inlineDiffService) return false;
-
-    await inlineDiffService.rejectAllChunks(cellId);
-    return true;
-  }
-
   /**
    * Log diff to console, now using diff2html for HTML portion
    */
@@ -565,7 +534,7 @@ export class NotebookDiffTools {
     const diffArr =
       operation === 'add' && nOld === ''
         ? nNew.split('\n').map(line => ({ line, type: 'added' as const }))
-        : this.calculateDiff(nOld, nNew);
+        : NotebookDiffTools.calculateDiff(nOld, nNew);
 
     console.log(
       `--- DIFF for ${operation}${cellId ? ` on cell ${cellId}` : ''} ---`
