@@ -5,6 +5,8 @@ import { IChatService } from './IChatService';
 import { AnthropicStreamHandler } from './AnthropicStreamHandler';
 import { AnthropicMessageCreator } from './AnthropicMessageCreator';
 import { ServiceUtils } from './ServiceUtils';
+import { AppStateService } from '../AppState';
+import { checkTokenLimit } from '../utils/tokenUtils';
 
 /**
  * Service for handling Anthropic API interactions
@@ -172,7 +174,7 @@ export class AnthropicService implements IChatService {
    * @param onTextChunk Callback for streaming text chunks as they arrive
    * @param onToolUse Callback for streaming tool uses as they arrive
    * @param notebookContextManager Optional NotebookContextManager to get context cells
-   * @param notebookPath Optional notebook path for context cells
+   * @param notebookId Optional notebook path for context cells
    * @param forceRetry Whether to force a retry even for 400 errors
    */
   async sendMessage(
@@ -185,7 +187,7 @@ export class AnthropicService implements IChatService {
     onTextChunk?: (text: string) => void,
     onToolUse?: (toolUse: any) => void,
     notebookContextManager?: any,
-    notebookPath?: string,
+    notebookId?: string,
     errorLogger?: (message: any) => Promise<void>,
     forceRetry: boolean = false
   ): Promise<any> {
@@ -209,7 +211,7 @@ export class AnthropicService implements IChatService {
         onTextChunk,
         onToolUse,
         notebookContextManager,
-        notebookPath,
+        notebookId,
         errorLogger
       );
 
@@ -230,7 +232,7 @@ export class AnthropicService implements IChatService {
         onTextChunk,
         onToolUse,
         notebookContextManager,
-        notebookPath,
+        notebookId,
         errorLogger,
         forceRetry
       );
@@ -387,10 +389,15 @@ export class AnthropicService implements IChatService {
     errorLogger?: (message: any) => Promise<void>
   ): Promise<any[]> {
     try {
-      return ServiceUtils.filterToolMessages(
-        [...this.conversationHistory],
+      const filteredDiffs = ServiceUtils.filterDiffApprovalMessages(
+        this.conversationHistory
+      );
+      const filteredTools = ServiceUtils.filterToolMessages(
+        filteredDiffs,
         errorLogger
       );
+
+      return filteredTools;
     } catch (error) {
       const errMsg = {
         message: 'Error filtering tool messages',
@@ -414,7 +421,7 @@ export class AnthropicService implements IChatService {
     onTextChunk?: (text: string) => void,
     onToolUse?: (toolUse: any) => void,
     notebookContextManager?: any,
-    notebookPath?: string,
+    notebookId?: string,
     errorLogger?: (message: any) => Promise<void>
   ): Promise<any> {
     const stream = await this.createMessageStream(
@@ -424,7 +431,7 @@ export class AnthropicService implements IChatService {
       systemPromptMessages,
       fetchNotebookState,
       notebookContextManager,
-      notebookPath,
+      notebookId,
       errorLogger
     );
 
@@ -450,7 +457,7 @@ export class AnthropicService implements IChatService {
     systemPromptMessages?: string[],
     fetchNotebookState?: () => Promise<string>,
     notebookContextManager?: any,
-    notebookPath?: string,
+    notebookId?: string,
     errorLogger?: (message: any) => Promise<void>
   ): Promise<any> {
     try {
@@ -468,7 +475,7 @@ export class AnthropicService implements IChatService {
           systemPromptMessages,
           fetchNotebookState,
           notebookContextManager,
-          notebookPath,
+          notebookId: notebookId,
           abortSignal: this.abortController!.signal,
           errorLogger
         },
@@ -588,7 +595,7 @@ export class AnthropicService implements IChatService {
   }
 
   /**
-   * Executes retry logic
+   * Executes retry logic with progressive backoff
    */
   private async executeRetry(
     onRetry: (error: Error, attemptNumber: number) => Promise<void>,
@@ -606,70 +613,108 @@ export class AnthropicService implements IChatService {
   ): Promise<any> {
     this.requestStatus = ChatRequestStatus.RETRYING;
 
-    try {
-      await onRetry(error, 1);
+    // Progressive backoff delays: 5s, 15s, 30s
+    const retryDelays = [5000, 15000, 30000];
+    const maxRetries = retryDelays.length;
 
-      if (this.isRequestCancelled()) {
-        return ServiceUtils.createCancelledResponse(
-          errorLogger,
-          this.requestStatus
+    for (let attempt = 1; attempt <= maxRetries; attempt++) {
+      try {
+        await onRetry(error, attempt);
+
+        if (this.isRequestCancelled()) {
+          return ServiceUtils.createCancelledResponse(
+            errorLogger,
+            this.requestStatus
+          );
+        }
+
+        await this.waitForRetry(retryDelays[attempt - 1]);
+
+        if (this.isRequestCancelled()) {
+          return ServiceUtils.createCancelledResponse(
+            errorLogger,
+            this.requestStatus
+          );
+        }
+
+        this.abortController = new AbortController();
+
+        const result = await this.executeStreamRequest(
+          filteredHistory,
+          tools,
+          mode,
+          systemPromptMessages,
+          fetchNotebookState,
+          onTextChunk,
+          onToolUse,
+          notebookContextManager,
+          notebookPath,
+          errorLogger
         );
+
+        if (!this.isRequestCancelled()) {
+          this.requestStatus = ChatRequestStatus.COMPLETED;
+        }
+
+        return result;
+      } catch (retryError: any) {
+        if (this.isRequestCancelled()) {
+          return ServiceUtils.createCancelledResponse(
+            errorLogger,
+            this.requestStatus
+          );
+        }
+
+        // If this is the last attempt, throw the error
+        if (attempt === maxRetries) {
+          await errorLogger?.({
+            message: 'All retry attempts failed',
+            error:
+              retryError instanceof Error ? retryError.message : retryError,
+            requestStatus: this.requestStatus,
+            attemptNumber: attempt
+          });
+
+          this.requestStatus = ChatRequestStatus.ERROR;
+
+          AppStateService.getState().chatContainer?.chatWidget.llmStateDisplay.hide();
+
+          // Create a user-friendly error message
+          const friendlyErrorMessage =
+            retryError instanceof Error
+              ? retryError.message
+              : 'Unknown error occurred';
+
+          const finalError = new Error(
+            `Failed to connect to AI service after 3 attempts. ${friendlyErrorMessage}`
+          );
+
+          throw finalError;
+        }
+
+        // Log retry attempt failure but continue to next attempt
+        await errorLogger?.({
+          message: `Retry attempt ${attempt} failed, will try again`,
+          error: retryError instanceof Error ? retryError.message : retryError,
+          requestStatus: this.requestStatus,
+          attemptNumber: attempt
+        });
+
+        // Update error for next attempt
+        error = retryError;
       }
-
-      await this.waitForRetry();
-
-      if (this.isRequestCancelled()) {
-        return ServiceUtils.createCancelledResponse(
-          errorLogger,
-          this.requestStatus
-        );
-      }
-
-      this.abortController = new AbortController();
-
-      const result = await this.executeStreamRequest(
-        filteredHistory,
-        tools,
-        mode,
-        systemPromptMessages,
-        fetchNotebookState,
-        onTextChunk,
-        onToolUse,
-        notebookContextManager,
-        notebookPath,
-        errorLogger
-      );
-
-      if (!this.isRequestCancelled()) {
-        this.requestStatus = ChatRequestStatus.COMPLETED;
-      }
-
-      return result;
-    } catch (retryError: any) {
-      if (this.isRequestCancelled()) {
-        return ServiceUtils.createCancelledResponse(
-          errorLogger,
-          this.requestStatus
-        );
-      }
-
-      await errorLogger?.({
-        message: 'Error during retry attempt',
-        error: retryError instanceof Error ? retryError.message : retryError,
-        requestStatus: this.requestStatus
-      });
-
-      this.requestStatus = ChatRequestStatus.ERROR;
-      throw retryError;
     }
+
+    // This should never be reached, but TypeScript needs it
+    throw error;
   }
 
   /**
    * Waits before retry with cancellation checking
    */
-  private async waitForRetry(): Promise<void> {
+  private async waitForRetry(delayMs: number = 5000): Promise<void> {
     await new Promise(resolve => {
-      const timeoutId = setTimeout(resolve, 5000);
+      const timeoutId = setTimeout(resolve, delayMs);
 
       const intervalId = setInterval(() => {
         if (this.isRequestCancelled()) {
@@ -679,7 +724,7 @@ export class AnthropicService implements IChatService {
         }
       }, 500);
 
-      setTimeout(() => clearInterval(intervalId), 5000);
+      setTimeout(() => clearInterval(intervalId), delayMs);
     });
   }
 
