@@ -1,6 +1,8 @@
 import { JupyterFrontEnd } from '@jupyterlab/application';
 import { ICommandPalette } from '@jupyterlab/apputils';
 import { AppStateService } from './AppState';
+import { StateDBCachingService, STATE_DB_KEYS } from './utils/stateDBCaching';
+import { inlineDiffService } from './Notebook/InlineDiffService';
 
 /**
  * Register all commands for the sage-ai extension
@@ -29,6 +31,12 @@ export function registerCommands(
 
   // Register fix tracking IDs command
   registerFixTrackingIDsCommand(app, palette);
+
+  // Register export error logs command
+  registerExportErrorLogsCommand(app, palette);
+
+  // Register clear error logs command
+  registerClearErrorLogsCommand(app, palette);
 }
 
 /**
@@ -154,11 +162,27 @@ function registerTestAddWithDiffCommand(
 
       // Step 5: Show approval dialog using the notebook widget for proper positioning
       const activeNotebook = notebooks.currentWidget;
+
+      // Get unique_id from notebook metadata to use as notebook ID
+      let notebookUniqueId: string | null = null;
+      if (activeNotebook) {
+        try {
+          const contentManager = AppStateService.getContentManager();
+          const nbFile = await contentManager?.get(activeNotebook.context.path);
+          if (nbFile?.content?.metadata?.sage_ai?.unique_id) {
+            notebookUniqueId = nbFile.content.metadata.sage_ai.unique_id;
+          }
+        } catch (error) {
+          console.warn('Could not get notebook metadata in commands:', error);
+        }
+      }
+
       const result = await diffManager.showApprovalDialog(
         activeNotebook ? activeNotebook.node : document.body,
         false, // Use standard dialog mode for notebook context
         false, // Not a run context
-        activeNotebook ? activeNotebook.context.path : null // Pass the notebook path
+        notebookUniqueId ||
+          (activeNotebook ? activeNotebook.context.path : null) // Pass the unique_id as notebook ID
       );
       console.log('Diff approval result:', result);
 
@@ -526,3 +550,74 @@ function registerFixTrackingIDsCommand(
   // Add this command to the command palette
   palette.addItem({ command: fixTrackingIDsCommand, category: 'AI Tools' });
 }
+
+/**
+ * Register the export error logs command
+ */
+function registerExportErrorLogsCommand(
+  app: JupyterFrontEnd,
+  palette: ICommandPalette
+): void {
+  const exportErrorLogsCommand: string = 'sage-ai:export-error-logs';
+
+  app.commands.addCommand(exportErrorLogsCommand, {
+    label: 'Export Error Logs to File',
+    execute: async () => {
+      try {
+        // Get error logs from stateDB
+        const errorLogs = await StateDBCachingService.getValue(
+          STATE_DB_KEYS.ERROR_LOGS,
+          ''
+        );
+
+        if (!errorLogs.trim()) {
+          console.log('No error logs found to export');
+          return;
+        }
+
+        // Get content manager to save the file
+        const contentManager = AppStateService.getContentManager();
+
+        // Save the error logs to error_dump.txt
+        await contentManager.save('./error_dump.txt', {
+          type: 'file',
+          format: 'text',
+          content: errorLogs
+        });
+
+        console.log('Error logs exported successfully to error_dump.txt');
+      } catch (error) {
+        console.error('Failed to export error logs:', error);
+      }
+    }
+  });
+
+  // Add this command to the command palette
+  palette.addItem({ command: exportErrorLogsCommand, category: 'AI Tools' });
+}
+
+/**
+ * Register the clear error logs command
+ */
+function registerClearErrorLogsCommand(
+  app: JupyterFrontEnd,
+  palette: ICommandPalette
+): void {
+  const clearErrorLogsCommand: string = 'sage-ai:clear-error-logs';
+
+  app.commands.addCommand(clearErrorLogsCommand, {
+    label: 'Clear Error Logs',
+    execute: async () => {
+      try {
+        // Clear error logs from stateDB
+        await StateDBCachingService.setValue(STATE_DB_KEYS.ERROR_LOGS, '');
+        console.log('Error logs cleared successfully');
+      } catch (error) {
+        console.error('Failed to clear error logs:', error);
+      }
+    }
+  });
+
+  // Add this command to the command palette
+  palette.addItem({ command: clearErrorLogsCommand, category: 'AI Tools' });
+}
