@@ -244,7 +244,7 @@ export const plugin: JupyterFrontEndPlugin<void> = {
     const planStateDisplay = new PlanStateDisplay();
     const waitingUserReplyBoxManager = new WaitingUserReplyBoxManager();
 
-    // Set the notebook tracker in the tool service
+    // Set the did y tracker in the tool service
     toolService.setNotebookTracker(notebooks, waitingUserReplyBoxManager);
 
     // Set the content manager in the tool service
@@ -351,9 +351,13 @@ export const plugin: JupyterFrontEndPlugin<void> = {
         const nbFile = await contentManager.get(notebook.context.path);
         let notebookUniqueId: string | null = null;
 
-        if (nbFile) {
+        console.log('================== NEW NOTEBOOK FILE =================');
+        console.log(nbFile);
+
+        if (nbFile && nbFile.content) {
           // get notebook metadata
-          if (!nbFile.content.metadata) return;
+          if (!nbFile.content.metadata || !nbFile.content.nbformat) return;
+
           const nbMetadata = nbFile.content.metadata || {};
 
           if (!nbMetadata.sage_ai || !nbMetadata.sage_ai.unique_id) {
@@ -365,9 +369,6 @@ export const plugin: JupyterFrontEndPlugin<void> = {
             nbFile.content.metadata = nbMetadata;
             if (nbFile.content.metadata) {
               // only save if metadata exists
-              console.error(
-                '[Plugin] Notebook metadata is missing, id creation failed'
-              );
               await contentManager.save(notebook.context.path, nbFile);
             }
 
